@@ -95,20 +95,20 @@ use vars qw{
   @site_rules_path
 };
 
-$VERSION = "3.001007";      # update after release (same format as perl $])
-# $IS_DEVEL_BUILD = 1;        # change for release versions
+$VERSION = "3.001008";      # update after release (same format as perl $])
+#$IS_DEVEL_BUILD = 1;        # change for release versions
 
 @ISA = qw();
 
 # SUB_VERSION is now just <yyyy>-<mm>-<dd>
-$SUB_VERSION = (split(/\s+/,'$LastChangedDate: 2006-10-05 10:59:08 -0700 (Thu, 05 Oct 2006) $ updated by SVN'))[1];
+$SUB_VERSION = (split(/\s+/,'$LastChangedDate: 2007-02-13 10:18:58 -0800 (Tue, 13 Feb 2007) $ updated by SVN'))[1];
 
 # If you hacked up your SA, you should add a version_tag to your .cf files.
 # This variable should not be modified directly.
 @EXTRA_VERSION = qw();
 if (defined $IS_DEVEL_BUILD && $IS_DEVEL_BUILD) {
   push(@EXTRA_VERSION,
-       ('r' . qw{$LastChangedRevision: 453304 $ updated by SVN}[1]));
+       ('r' . qw{$LastChangedRevision: 507135 $ updated by SVN}[1]));
 }
 
 sub Version {
@@ -222,6 +222,12 @@ found in the SpamAssassin B<rules> directory.
 If set to 1, no tests that require internet access will be performed. (default:
 0)
 
+=item ignore_site_cf_files
+
+If set to 1, any rule files found in the C<site_rules_filename> directory will
+be ignored.  *.pre files (used for loading plugins) found in the
+C<site_rules_filename> directory will still be used. (default: 0)
+
 =item dont_copy_prefs
 
 If set to 1, the user preferences file will not be created if it doesn't
@@ -1386,7 +1392,7 @@ sub init {
     }
 
     $fname = $siterules;
-    if ($fname) {
+    if ($fname && !$self->{ignore_site_cf_files}) {
       $self->{config_text} .= $self->read_cf ($fname, 'site rules dir');
     }
 
